@@ -548,7 +548,7 @@ class Connector:
         if device_id == '__ALL_DEVICES__':
             raw = deepcopy(self.__latest_data)
         else:
-            raw = deepcopy(self.__current_data_frame[device_id])
+            raw = deepcopy(self.__current_data_frame[device_id]) if (device_id in self.__current_data_frame) else None
 
         if raw is None:
             if data_type is None:
@@ -1476,7 +1476,7 @@ class Connector:
             elif data['type'] == DataType.SPRITE_CLICKED:
                 self.__callback('on_sprite_clicked', data)
 
-        if 'broadcast' in data and data['broadcast'] and self.on_broadcast_data is not None:
+        if 'broadcast' in data and data['broadcast'] and self.on_broadcast_data != noop:
             self.__callback('on_broadcast_data', data)
         else:
             self.__callback('on_data', data)
